var rcpapiadapter = angular.module('rcp-api-adapter', ['ionic']);

//rcpapiadapter.constant('apiUrl', 'http://www.rcpparking.com/api/');
rcpapiadapter.constant('apiUrl', 'http://www.rcpparking.com/api/');
rcpapiadapter.constant('version', 'v1');
rcpapiadapter.constant('apiHeader', 'X-RCP-Token');

rcpapiadapter.factory('api', ['$ionicPopup', '$ionicLoading', '$ionicHistory', '$state', '$http', '$q', 'apiUrl', 'apiHeader', 'version',
    function($ionicPopup, $ionicLoading, $ionicHistory, $state, $http, $q, apiUrl, apiHeader, version) {
        // Main factory API object
        var apiFactory = {};
        apiFactory.isHalting = false;
        apiFactory.timeout = 60000;

        Array.prototype.contains = function(element){
            var found = false;

            this.forEach(function(name) {
                if (element.indexOf(name) > -1) {
                    found = true;
                }
            });

            return found;
        };

        apiFactory.nonRedirectUrls = [
            "/login",
            "/users",
            "/password-reset"
        ];

        function request($http, $request) {
            var deferred = $q.defer();

            $http($request).success(function(data, status) {
                deferred.resolve(data);
            }).error(function(data, status) {
                if (status == 403) {
                    if (!apiFactory.isHalting) {
                        redirectToLogin();
                        showLoginRedirectPopup();
                    }
                } else if (status == 0) {
                    if (!apiFactory.isHalting) {
                        offlineRedirect($request.url);
                    }
                } else {
                    deferred.reject(data);
                }
            });

            return deferred.promise;
        }

        function redirectToLogin() {
            apiFactory.isHalting = true;

            $ionicLoading.hide();
            apiFactory.deleteToken();
            apiFactory.deleteUserId();

            $ionicHistory.clearHistory();
            $ionicHistory.nextViewOptions({
                disableAnimate: false,
                disableBack: true
            });

            $state.go('login');
        }

        function showLoginRedirectPopup() {
            var alertPopup = $ionicPopup.alert({
                title: 'Logged Out',
                template: 'You were logged out because your session has expired.'
            });
            alertPopup.then(function() {
                apiFactory.isHalting = false;
            });
        }

        function offlineRedirect($url) {
            apiFactory.isHalting = true;
            $ionicLoading.hide();

            $ionicHistory.clearHistory();
            $ionicHistory.nextViewOptions({
                disableAnimate: false,
                disableBack: true
            });

            if (apiFactory.nonRedirectUrls.contains($url)) {
                $state.go('login');
            } else {
                $state.go('tabs.dashboard');
            }

            showOfflineRedirectPopup();
        }

        function showOfflineRedirectPopup() {
            var alertPopup = $ionicPopup.alert({
                title: 'Error',
                template: 'You are not connected to the internet or your signal strength is low.'
            });
            alertPopup.then(function() {
                apiFactory.isHalting = false;
            });
        }

        /*
        * API methods for saving tokens
        */
        apiFactory.saveToken = function($token) {
            localStorage.setItem('token', $token);
        };

        apiFactory.getToken = function() {
            return localStorage.getItem('token');
        };

        apiFactory.deleteToken = function() {
            localStorage.removeItem('token'); 
        };

		apiFactory.saveVehicleReminder = function() {
			localStorage.setItem('vehicleReminder', true);
		}

		apiFactory.getVehicleReminder = function() {
            return localStorage.getItem('vehicleReminder');
		};

        /*
        * API methods for saving user id's
        */
        apiFactory.saveUserId = function($token) {
            localStorage.setItem('id', $token);
        };

        apiFactory.getUserId = function() {
            return localStorage.getItem('id');
        };

        apiFactory.deleteUserId = function() {
            localStorage.removeItem('id'); 
        };

        apiFactory.saveLocationId = function($locationid) {
            localStorage.setItem('locationid', $locationid);
        };

        apiFactory.deleteLocationId = function() {
            localStorage.removeItem('location'); 
        };

        apiFactory.getLocationId = function() {
            return localStorage.getItem('locationid');
        };

        apiFactory.saveVehicleId = function($vehicleid) {
            localStorage.setItem('vehicleid', $vehicleid);
        };

        apiFactory.getVehicleId = function() {
            return localStorage.getItem('vehicleid');
        };

        /* Get the vehicle types */

        apiFactory.getVehicleTypes = function() {
            var $request = {
                data: {},
                method: 'GET',
                url: apiUrl+version+'/vehicle-types',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        /*
        *  Users API methods
        */

        apiFactory.register = function($user) {
            if ($user == null) {
                $user = {};
            }

            var $request = {
                data: $user,
                method: 'POST',
                url: apiUrl+version+'/users',
                headers: {
                    'Content-Type': 'application/json'
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.login = function($user) {
            if ($user == null) {
                $user = {};
            }

            var $request = {
                data: $user,
                method: 'POST',
                url: apiUrl+version+'/login',
                headers: {
                    'Content-Type': 'application/json'
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.logOut = function() {
            var $request = {
                method: 'DELETE',
                url: apiUrl+version+'/login',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.getVehicles = function() {
            var $request = {
                method: 'GET',
                url: apiUrl+version+'/users/'+this.getUserId()+'/vehicles',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.getParkedVehicles = function() {
            var $request = {
                method: 'GET',
                url: apiUrl+version+'/vehicle/'+this.getUserId()+'/parkedvehicles',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.addVehicle = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+version+'/users/'+this.getUserId()+'/vehicles',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.deleteVehicle = function(vehicleId, data) {
            var $request = {
                method: 'DELETE',
                url: apiUrl+version+'/users/'+this.getUserId()+'/vehicles/'+vehicleId,
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.getTransactions = function() {
            var $request = {
                method: 'GET',
                url: apiUrl+version+'/users/'+this.getUserId()+'/transactions/page/0',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.changePassword = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+version+'/users/'+this.getUserId()+'/password',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.resetPassword = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+version+'/password-reset',
                headers: {
                    'Content-Type': 'application/json',
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.getNearestLocations = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+version+'/locations/nearest',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

		apiFactory.getSearchLocations = function(data) {
			if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+'v2/locations/search',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
		}

        apiFactory.setPaymentData = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'POST',
                data: data,
                url: apiUrl+version+'/transaction/'+this.getUserId()+'/setpaymentdata',
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.locationSelect = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'GET',
                data: data,
                url: apiUrl+version+'/transaction/'+this.getUserId()+'/setlocation/'+data,
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };
            this.saveLocationId(data);

            return request($http, $request);
        };

        apiFactory.vehicleSelect = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'GET',
                data: data,
                url: apiUrl+version+'/transaction/'+this.getUserId()+'/setvehicle/'+data,
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };
            this.saveVehicleId(data);

            return request($http, $request);
        };

        apiFactory.getLocationDetails = function(data) {
            if (data == null) {
                data = {};
            }

            var $request = {
                method: 'GET',
                data: data,
                url: apiUrl+version+'/transaction/locationdetails/'+this.getLocationId(),
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        apiFactory.getPaymentOptions = function(data) {
            if (data == null) {
                data = {};
            }

            var vtype = this.getVehicleId().toString();
            var vPart = vtype.split(",");

            var $request = {
                method: 'GET',
                data: data,
                url: apiUrl+'v2/'+'transaction/paymentoptions/'+this.getLocationId()+"/"+vPart[0],
                headers: {
                    'Content-Type': 'application/json',
                    'X-RCP-Token': this.getToken() 
                },
                timeout: apiFactory.timeout
            };

            return request($http, $request);
        };

        return apiFactory;
    }
]);
