angular.module( 'rcp-dashboard', ['ionic', 'rcp-api-adapter', 'rcp-loading-indicator-service', 'rcp-current-parked-service'])

.config(function($stateProvider, $urlRouterProvider) {
    $stateProvider
    .state('tabs.dashboard', {
        url: '/dashboard',
        views: {
            'dash-tab': {
                controller: 'DashboardCtrl',
                templateUrl: 'app/components/dashboard/dashboard.html',
            }
        }
    });
})

.controller('DashboardCtrl', function(api, currentParked, $scope, $state, $ionicHistory, loadingIndicator, $ionicLoading, $ionicPopup, $location) {
    $scope.logOut = function() {
        $ionicHistory.nextViewOptions({
            disableAnimate: true,
            disableBack: true
        });

        loadingIndicator.showLoadingScreen($scope, 'Logging you out...');
        var logout = api.logOut();
        logout.then(function(response) {
            api.deleteToken();
            api.deleteUserId();
            api.deleteLocationId();

            $ionicLoading.hide();
            $location.path("/login");
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert(reason.error); 
        });
    };

    $scope.$on('$ionicView.beforeEnter', function(){
		if (!api.getVehicleReminder()) {
			var alertPopup = $ionicPopup.alert({
				title: 'Welcome to MobilePay',
				template: "Pick and choose from a wide range of parking locations Nationwide.<br><br>Remember to add a vehicle before you start parking."
			});
			api.saveVehicleReminder();
		}

        var parkedvehicles = api.getParkedVehicles();
        parkedvehicles.then(function(response) {
            if(parkedVehiclesCheck(response.data)){
                $scope.existsParked = true;
            } else {
                $scope.existsParked = false;
            }

            $scope.parkedvehicles = response.data;
            $ionicLoading.hide();
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert(reason.error); 
        });
    });

    function parkedVehiclesCheck(data){
        for (var vehicle in data) {
            if(data[vehicle].parked){
                return true;
            }
        }
        return false;
    }

    $scope.showTerms = function() {
        $state.go('tabs.terms');
    };

    $scope.showVehicles = function() {
        $state.go('tabs.vehicle-list', { cache: false });
    };

    $scope.showPaymentDetails = function() {
        $state.go('tabs.payment-details');
    };

    $scope.showPayParking = function() {
        $state.go('tabs.pay-parking');
    }

    $scope.showContact = function() {
        $state.go('tabs.contact-settings');
    }

    $scope.showSecurity = function() {
        $state.go('tabs.security');
    }

    $scope.showExtend = function(carType,carId,locationId) {
        if(typeof carType == 'number'){
            var vehicleSelect = api.vehicleSelect(carType+","+carId);
            var locationSelect = api.locationSelect(locationId);

            // console.log(api.getLocationId());

            $state.go('tabs.pay-parking-options');
        }
    }

    $scope.showAlert = function(message) {
        var alertPopup = $ionicPopup.alert({
            title: 'An error has occurred',
            template: message 
        });
    };
});
