angular.module( 'rcp-pay-parking-options', ['ionic', 'rcp-current-parked-service', 'rcp-loading-indicator-service', 'rcp-api-adapter'])

.config(function($stateProvider, $urlRouterProvider) {
	$stateProvider
	.state('tabs.pay-parking-options', {
		url: '/pay-parking-options',
		views: {
			'dash-tab@tabs': {
				controller: "PayParkingOptionsCtrl",
				templateUrl: "app/components/pay-parking-options/pay-parking-options.html"
			}
		}
	});
})

.controller('PayParkingOptionsCtrl', function(api, currentParked, $ionicModal, $ionicHistory, $scope, $state, $ionicPopup, $ionicLoading, loadingIndicator) {
	loadingIndicator.showLoadingScreen($scope, 'Fetching payment options...');

	var locationDetails = api.getLocationDetails();
	var isInternetOff = false;

	$scope.paymentData = {
		hour: 0,
		day: 0,
		week: 0,
		overnight: 0,
	};

	$scope.$on('$ionicView.afterEnter', function(){
		var locationDetails = api.getLocationDetails();
		locationDetails.then(function(response) {
			$scope.locationDetails = response.data[0];
			fetchPaymentOptions();
		}, function(reason) {
			$ionicLoading.hide();
			$scope.showAlert(reason.error); 
		});
	});

	function fetchPaymentOptions() {
		var paymentOptions = api.getPaymentOptions();
		paymentOptions.then(function(response) {
			$scope.paymentOptionsHours = json2array(response.data.hours);	
			$scope.paymentOptionsDays = json2array(response.data.days);	
			$scope.paymentOptionsWeeks = json2array(response.data.weeks);	
			$scope.paymentOptionsOvernight = json2array(response.data.overnight);	

			$ionicLoading.hide();
		}, function(reason) {
			$ionicLoading.hide();
			$scope.showAlert(reason.error); 
		});
	}

	$scope.beginPay = function(paymentData) {
		loadingIndicator.showLoadingScreen($scope, 'Fetching payment form...');
		var paymentSet = api.setPaymentData(paymentData);
		paymentSet.then(function(response) {
			$state.go('tabs.payment-process');
			$ionicLoading.hide();
		}, function(reason) {
			$ionicLoading.hide();
			$scope.showAlert('Error', reason.error, null);
		});
	}

	$scope.showAlert = function(title, message, callback) {
		if (!isInternetOff) {
			var alertPopup = $ionicPopup.alert({
				title: title,
				template: message 
			});

			alertPopup.then(function(res) {
				if (callback) {
					callback(res);
				}
			});
		}
	};

	$scope.checkValues = function() {
		return !$scope.terms; 
	};

	$scope.viewTerms = function() {
		$state.go('tabs.terms');
	};

	function json2array(json){
		if (!json) {
			return null;
		}
		var result = [];
		var keys = Object.keys(json);
		keys.forEach(function(key){
			result.push(json[key]);
		});
		return result;
	}
});
