angular.module( 'rcp-pay-parking', ['ionic', 'rcp-loading-indicator-service'])

.config(function($stateProvider, $urlRouterProvider) {
    $stateProvider
    .state('tabs.pay-parking', {
        url: '/pay-parking',
        views: {
            'dash-tab@tabs': {
                controller: "PayParkingCtrl",
                templateUrl: "app/components/pay-parking/pay-parking.html"
            }
        }
    });
})

.controller('PayParkingCtrl', function(api, $ionicPopup, $scope, $state, $ionicHistory, loadingIndicator, $ionicLoading) {
    $scope.showParkingOptions = function(payment) {
        var locationSelect = api.locationSelect(payment.locationNumber);
        var vehicleSelect = api.vehicleSelect(payment.vehicleData);
        loadingIndicator.showLoadingScreen($scope, 'Preparing your details...');
        locationSelect.then(function(response) {
            $ionicLoading.hide();
            $state.go('tabs.pay-parking-options');
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert('Error', reason.error, null);
        });
    }

    function findVehicles() {
        loadingIndicator.showLoadingScreen($scope, 'Finding your vehicles...');
        var vehicles = api.getVehicles();
        vehicles.then(function(response) {
            $scope.vehicles = response.data;
            $ionicLoading.hide();
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert(reason.error); 
        });
    };

    $scope.showParkingAlert = function() {
        var alertPopup = $ionicPopup.alert({
            title: 'Please Park',
            template: 'Please ensure you are <strong>parked</strong> before continuing'
        });
        alertPopup.then(function(res) {
            $ionicHistory.goBack();
        });
    };

    $scope.showParkedModal = function() {
        var parkedModal = $ionicPopup.show({
            template: '',
            title: 'Are you already parked?',
            scope: $scope,
            buttons: [
                { text: 'No' },
                {
                    text: '<b>Yes</b>',
                    type: 'button-positive',
                    onTap: function(e) {
                        return true;
                    }
                },
            ]
        });
        parkedModal.then(function(res) {
            if (res) {
                findVehicles();
            } else {
                $scope.showParkingAlert(); 
            }
        });
    };

    $scope.showAlert = function(title, message, callback) {
        var alertPopup = $ionicPopup.alert({
            title: title,
            template: message 
        });

        alertPopup.then(function(res) {
            if (callback) {
                callback(res);
            }
        });
    };

    $scope.showParkedModal();
});
