angular.module( 'rcp-vehicle-list', ['ionic', 'rcp-loading-indicator-service', 'rcp-api-adapter'])

.config(function($stateProvider, $urlRouterProvider) {
    $stateProvider
    .state('tabs.vehicle-list', {
        url: '/vehicle-list',
        views: {
            'dash-tab@tabs': {
                controller: "VehicleListCtrl",
                templateUrl: "app/components/vehicle-list/vehicle-list.html"
            }
        }
    });
})

.controller('VehicleListCtrl', function(api, $ionicModal, $ionicHistory, $scope, $state, $ionicPopup, $ionicLoading, loadingIndicator) {
    loadingIndicator.showLoadingScreen($scope, 'Finding your vehicles...');

    $scope.$on('$ionicView.beforeEnter', function(){
        var vehicleTypes = api.getVehicleTypes();
        vehicleTypes.then(function(response) {
            $ionicLoading.hide();
            $scope.vehicleTypes = response.data;
            fetchVehicles();
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert(reason.error); 
        });
    });

    function fetchVehicles() {
        var vehicles = api.getVehicles();
        vehicles.then(function(response) {
            $scope.vehicles = response.data;
        }, function(reason) {
            $ionicLoading.hide();
            $scope.showAlert(reason.error); 
        });
    }

    $scope.showAlert = function(message) {
        var alertPopup = $ionicPopup.alert({
            title: 'Error',
            template: message 
        });
    };

    /* Deleting Vehicles */

    $scope.vm = {
        showDelete: false 
    };

    $scope.showDelete = function() {
        $scope.vm.showDelete = !$scope.vm.showDelete;
    };

    $scope.deleteVehicle = function(index) {
        $scope.confirmDelete(index);
    };

    function deleteVehicle(index) {
        var id = $scope.vehicles[index].id;

        var deleteVehicle = api.deleteVehicle(id);
        deleteVehicle.then(function(response) {
            $scope.vehicles.splice(index, 1)  
            $ionicLoading.hide();
            $scope.vm.showDelete = false;
        }, function(reason) {
            $ionicLoading.hide();
            if (reason.status == 400) {
                errors = JSON.stringify(reason.errors);
                $scope.showAlert('Some required fields are missing: ' + errors); 
            } else {
                $scope.showAlert(reason.errors); 
            }
        });
    }

    $scope.confirmDelete = function(index) {
        var confirmDelete = $ionicPopup.show({
            template: '',
            title: 'Are you sure you wish to delete the vehicle?',
            scope: $scope,
            buttons: [
                { text: 'No' },
                {
                    text: '<b>Delete</b>',
                    type: 'button-assertive',
                    onTap: function(e) {
                        return true;
                    }
                },
            ]
        });
        confirmDelete.then(function(res) {
            if (res) {
                deleteVehicle(index);
            }
        });
    };

    /* Adding Vehicles */

    $ionicModal.fromTemplateUrl('vehicle-entry-modal.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function(modal) {
        $scope.modal = modal
    });

    $scope.openModal = function() {
        $scope.modal.show()
    };

    $scope.cancelAdd = function() {
        $scope.modal.hide();
    };

    $scope.addVehicle = function(vehicle) {
        loadingIndicator.showLoadingScreen($scope, 'Adding vehicle...');

        var add = api.addVehicle(vehicle);
        add.then(function(response) {
            $scope.vehicles.push(response);
            $scope.modal.hide();
            $ionicLoading.hide();
        }, function(reason) {
            $ionicLoading.hide();
            if (reason.status == 400) {
                errors = JSON.stringify(reason.errors);
                $scope.showAlert('Some required fields are missing: ' + errors); 
            } else {
                $scope.showAlert(reason.errors); 
            }
        });
    };

    $scope.$on('$destroy', function() {
        $scope.modal.remove();
    });
});
